# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.search_shared_response_messages200_response_inner import SearchSharedResponseMessages200ResponseInner

class TestSearchSharedResponseMessages200ResponseInner(unittest.TestCase):
    """SearchSharedResponseMessages200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchSharedResponseMessages200ResponseInner:
        """Test SearchSharedResponseMessages200ResponseInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchSharedResponseMessages200ResponseInner`
        """
        model = SearchSharedResponseMessages200ResponseInner()
        if include_optional:
            return SearchSharedResponseMessages200ResponseInner(
                call_id = '',
                index = 1.337,
                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                duration = 1.337,
                seconds_from_start = 1.337,
                message = '',
                role = '',
                recording_url = ''
            )
        else:
            return SearchSharedResponseMessages200ResponseInner(
                call_id = '',
                index = 1.337,
                time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                duration = 1.337,
                seconds_from_start = 1.337,
                message = '',
                role = '',
        )
        """

    def testSearchSharedResponseMessages200ResponseInner(self):
        """Test SearchSharedResponseMessages200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
