# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from keplar_api.models.invite_customer_item import InviteCustomerItem
from typing import Optional, Set
from typing_extensions import Self

class InviteCustomersRequest(BaseModel):
    """
    InviteCustomersRequest
    """ # noqa: E501
    customers: Annotated[List[InviteCustomerItem], Field(min_length=1, max_length=50)]
    org_name: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=200)]] = Field(default=None, alias="orgName")
    is2_fa_enabled: Optional[StrictBool] = Field(default=None, alias="is2FAEnabled")
    default_workspace_id: Optional[StrictStr] = Field(default=None, alias="defaultWorkspaceId")
    create_default_workspace: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=200)]] = Field(default=None, alias="createDefaultWorkspace")
    additional_workspace_ids: Optional[List[StrictStr]] = Field(default=None, alias="additionalWorkspaceIds")
    __properties: ClassVar[List[str]] = ["customers", "orgName", "is2FAEnabled", "defaultWorkspaceId", "createDefaultWorkspace", "additionalWorkspaceIds"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of InviteCustomersRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in customers (list)
        _items = []
        if self.customers:
            for _item_customers in self.customers:
                if _item_customers:
                    _items.append(_item_customers.to_dict())
            _dict['customers'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of InviteCustomersRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "customers": [InviteCustomerItem.from_dict(_item) for _item in obj["customers"]] if obj.get("customers") is not None else None,
            "orgName": obj.get("orgName"),
            "is2FAEnabled": obj.get("is2FAEnabled"),
            "defaultWorkspaceId": obj.get("defaultWorkspaceId"),
            "createDefaultWorkspace": obj.get("createDefaultWorkspace"),
            "additionalWorkspaceIds": obj.get("additionalWorkspaceIds")
        })
        return _obj


