# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.update_call_for_code_invite_response_request import UpdateCallForCodeInviteResponseRequest

class TestUpdateCallForCodeInviteResponseRequest(unittest.TestCase):
    """UpdateCallForCodeInviteResponseRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateCallForCodeInviteResponseRequest:
        """Test UpdateCallForCodeInviteResponseRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateCallForCodeInviteResponseRequest`
        """
        model = UpdateCallForCodeInviteResponseRequest()
        if include_optional:
            return UpdateCallForCodeInviteResponseRequest(
                call_id = '',
                call = keplar_api.models.update_call_for_code_invite_response_request_call.updateCallForCodeInviteResponse_request_call(
                    vendor_call_id = '', 
                    status = 'REQUESTED', )
            )
        else:
            return UpdateCallForCodeInviteResponseRequest(
                call_id = '',
                call = keplar_api.models.update_call_for_code_invite_response_request_call.updateCallForCodeInviteResponse_request_call(
                    vendor_call_id = '', 
                    status = 'REQUESTED', ),
        )
        """

    def testUpdateCallForCodeInviteResponseRequest(self):
        """Test UpdateCallForCodeInviteResponseRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
