# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.get_workspace_members200_response import GetWorkspaceMembers200Response

class TestGetWorkspaceMembers200Response(unittest.TestCase):
    """GetWorkspaceMembers200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetWorkspaceMembers200Response:
        """Test GetWorkspaceMembers200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetWorkspaceMembers200Response`
        """
        model = GetWorkspaceMembers200Response()
        if include_optional:
            return GetWorkspaceMembers200Response(
                items = [
                    keplar_api.models.workspace_member_item.WorkspaceMemberItem(
                        id = '', 
                        user_id = '', 
                        role = '', 
                        user = keplar_api.models.workspace_member_user.WorkspaceMemberUser(
                            id = '', 
                            name = '', 
                            email = '', ), 
                        created_at = '', )
                    ]
            )
        else:
            return GetWorkspaceMembers200Response(
                items = [
                    keplar_api.models.workspace_member_item.WorkspaceMemberItem(
                        id = '', 
                        user_id = '', 
                        role = '', 
                        user = keplar_api.models.workspace_member_user.WorkspaceMemberUser(
                            id = '', 
                            name = '', 
                            email = '', ), 
                        created_at = '', )
                    ],
        )
        """

    def testGetWorkspaceMembers200Response(self):
        """Test GetWorkspaceMembers200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
